#
# spec file for package perl-AnyEvent-HTTP
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name AnyEvent-HTTP
Name:           perl-AnyEvent-HTTP
Version:        2.250.0
Release:        1.1
# 2.25 -> normalize -> 2.250.0
%define cpan_version 2.25
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple but non-blocking HTTP/HTTPS client
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(AnyEvent) >= 5.330
BuildRequires:  perl(common::sense) >= 3.300
Requires:       perl(AnyEvent) >= 5.330
Requires:       perl(common::sense) >= 3.300
Provides:       perl(AnyEvent::HTTP) = %{version}
%undefine       __perllib_provides
Recommends:     perl(URI)
%{perl_requires}

%description
This module is an AnyEvent user, you need to make sure that you use and run
a supported event loop.

This module implements a simple, stateless and non-blocking HTTP client. It
supports GET, POST and other request methods, cookies and more, all on a
very low level. It can follow redirects, supports proxies, and
automatically limits the number of connections to the values specified in
the RFC.

It should generally be a "good client" that is enough for most HTTP tasks.
Simple tasks should be simple, but complex tasks should still be possible
as the user retains control over request and response headers.

The caller is responsible for authentication management, cookies (if the
simplistic implementation in this module doesn't suffice), referer and
other high-level protocol details for which this module offers only limited
support.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license COPYING

%changelog
* Tue Jun  3 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Tue Apr 28 2020 <timueller+perl@suse.de>
- updated to 2.25
  see /usr/share/doc/packages/perl-AnyEvent-HTTP/Changes
  TODO: cookie_jar_extract should refuse when host is an ip literal
  TODO: cookie_jar_et_cookie should reject cookies not matching their down server domain
  TODO: cookie prefixes? https://tools.ietf.org/html/draft-ietf-httpbis-cookie-prefixes-00
  TODO: default rbuf_max limit for header-reading, chunk header reading etc.
  2.25 Mon Apr 27 14:11:40 CEST 2020
  - fix incorrectly sending proxy requests to origin servers
    when reusing proxy connections (analyzed and testcase by Ivan Robert).
  - the sessionid parameter was documented as session in random
    places - fix docs and keep using sessionid in the code as before.
  - fix cookie format documentation.
* Fri Aug 31 2018 coolo@suse.com
- updated to 2.24
  see /usr/share/doc/packages/perl-AnyEvent-HTTP/Changes
* Mon Aug 29 2016 coolo@suse.com
- updated to 2.23
  see /usr/share/doc/packages/perl-AnyEvent-HTTP/Changes
  TODO: default rbuf_max value maybe? how about reading large chunks in small parts?
  2.23 Sun Aug 28 11:30:33 CEST 2016
  - relative redirects used the proxy schema instead of the request
    url schema to generate the new url, which is wrong (analyzed by Felix
    Ostmann).
  - fix download example (reported by Felix Ostmann).
* Thu May 14 2015 coolo@suse.com
- updated to 2.22
  see /usr/share/doc/packages/perl-AnyEvent-HTTP/Changes
* Fri Jul 25 2014 coolo@suse.com
- updated to 2.21
  - correctly keep body when redirecting POSTs, instead of
    deleting them.
  2.2  Mon Jun  9 01:31:46 CEST 2014
  - connection header was malformed (patch by Raphael Geissert).
  - add lots of known idempotent methods from httpbis.
  - implement relative location headers (rfc 7231), with fallback on URI.
  - add support for status code 308 from rfc 7238.
  - recommend URI.
* Mon Jun  3 2013 coolo@suse.com
- updated to 2.15
  - use the recurse parameter to also limit the number of retries to be
    done, avodiing endless loops with broken servers, as reported
    by Carl Chambers.
* Fri May 25 2012 coolo@suse.com
- updated to 2.14
  - Time::Local::timegm croaks on out-of-range values. Don't let
    this disturb AnyEvent::HTTP (reported by: tell me, I forgot...).
* Thu Aug 25 2011 chris@computersalat.de
- update to 2.13
  - garbled chunked responses caused AnyEvent::HTTP to malfunction
    (patch by Dmitri Melikyan).
  - fix GET => HEAD in one case in the documentation (James Bromberger).
- fix deps
  * perl(AnyEvent) >= 5.33
  * perl(common::sense) >= 3.3
* Tue Jun 14 2011 coolo@novell.com
- updated to 2.12
  - fix a possible 'Can't call method "destroyed"' error (which would
    have been reported by Carl Chambers).
  - the keepalive session cache wouldn't take port and scheme into account
    when reusing connection - potentially causing information leaks
    (reported by Nick Kostirya).
  - bump AnyEvent dependency version (reported by Richard Harris).
  - the keepalive and persistent parameters were actually named
    differently in the code - they now work as documented.
  - fix a bug where callbacks would sometimes never be called when
    the request timeout is near or below the persistent connection
    timeout (testcase by Cindy Wang).
  - destroying the guard would have no effect when a request was
    recursing or being retired.
  - "proxy => undef" now overrides any global proxy when specified.
  - require scheme in urls, also use a stricter match to match urls,
    leading or trailing garbage is no longer tolerated.
  - EXPERIMENTAL: allow '=' in cookie values.
  - do not lowercase cookie names, only parameter names.
  - add missing dependency on common::sense.
  - add a resume download example.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Oct  7 2010 pascal.bleser@opensuse.org
- initial package (1.46)
